pub struct MetadataGap {
pub field: String,
pub candidates: Option<u64>,
}Expand description
Missing metadata that prevented evaluating a supported filter for candidates.
Fields
field: StringProvider-defined filter field with missing values.
candidates: Option<u64>Candidates omitted while producing this page, if the provider can count them. Counts for different fields may refer to the same candidates.