pub struct MappedBytes {
backing: Arc<Mmap>,
range: Range<usize>,
}Expand description
A byte range that keeps its backing mapping alive after the source is dropped. The backing file must remain unchanged for the lifetime of every clone.
Fields
backing: Arc<Mmap>range: Range<usize>Trait Implementations
Sourceimpl AsRef<[u8]> for MappedBytes
impl AsRef<[u8]> for MappedBytes
Sourceimpl Clone for MappedBytes
impl Clone for MappedBytes
Sourcefn clone(&self) -> MappedBytes
fn clone(&self) -> MappedBytes
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for MappedBytes
impl RefUnwindSafe for MappedBytes
impl Send for MappedBytes
impl Sync for MappedBytes
impl Unpin for MappedBytes
impl UnsafeUnpin for MappedBytes
impl UnwindSafe for MappedBytes