pub struct StoredTensor {
pub dtype: Dtype,
pub shape: Vec<u64>,
pub byte_strides: Vec<u64>,
pub data: DataSpan,
}Expand description
Byte strides also describe interleaved records without introducing a table-specific layout or treating packed 4-bit values as addressable bytes.
Fields
dtype: DtypeType of the addressable storage elements, such as packed U32 words.
shape: Vec<u64>Dimensions of the stored elements.
byte_strides: Vec<u64>Byte distance between adjacent elements along each axis.
data: DataSpanByte range containing the view, including any gaps between elements.
Implementations
Sourceimpl StoredTensor
impl StoredTensor