pub enum TensorEncoding {
Dense {
tensor: StoredTensor,
},
Affine {
bits: u8,
group_size: u64,
group_axis: usize,
packing: BitPacking,
codes: StoredTensor,
scales: StoredTensor,
offset: AffineOffset,
},
Ggml {
encoding: GgmlEncoding,
data: DataSpan,
},
Opaque {
name: String,
metadata: Value,
data: Vec<DataSpan>,
},
}Expand description
Storage layout and quantization metadata, with explicit references to all data.
Variants
Dense
Addressable scalar values with explicit shape and strides.
Fields

tensor: StoredTensorPhysical view of the scalar values.
Affine
Grouped integer codes reconstructed using scales and an affine offset.
Fields

packing: BitPackingOrder of codes within each storage word.

codes: StoredTensorPacked integer codes.

scales: StoredTensorOne scale per quantization group.

offset: AffineOffsetAdditive biases or integer zero points, one per group.
Ggml
GGML blocks whose layout is determined by the encoding code.
Opaque
Uninterpreted storage retained for a future adapter.
Implementations